@@ -5,7 +5,6 @@
 # it under the terms of the GNU General Public License version 3 as
 # published by the Free Software Foundation
 #
-from __future__ import unicode_literals
 import taglib
 from . import copy_test_file
 
@@ -13,7 +12,7 @@ from . import copy_test_file
 def test_string_value_is_converted_to_list(tmpdir):
     f = copy_test_file('testöü.flac', tmpdir)
     tf = taglib.File(f)
-    tf.tags['AAA'] = u'A TAG'
+    tf.tags['AAA'] = 'A TAG'
     tf.tags['BBB'] = b'ANOTHER TAG'
     tf.save()
     del tf
